/*
 * Copyright IBM Corporation, 2012
 * Author Kingsuk Deb <kingsdeb@linux.vnet.ibm.com>
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 3.0 of the GNU Lesser General Public License
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it would be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*/

#include <stdio.h>
#include <fipscheck.h>

int main(void)
{
    char buf[4096];
    const char *files[] = { "/usr/bin/fipscheck",
                     "/lib64/libfipscheck.so.1" };
    const char *libname = '\0', *symbolname = '\0';
    int FAILS = 0;

/* test FIPSCHECK_verify 
 * This will invoke fipscheck on either a shared library if both libname and
 * symbolname are not NULL or on the executable binary from which the
 * FIPSCHECK_verify was called. */
    if (FIPSCHECK_verify(libname, symbolname) != 1) {
        FAILS++;
        fprintf(stderr, "FIPSCHECK_verify FAIL\n");
    }

/* test FIPSCHECK_get_binary_path
 * Auxiliary function - returns path pointing to the executable file which is
 * being run. The path buffer must be large enough to hold the path, otherwise
 * it is truncated. */        
    if (FIPSCHECK_get_binary_path(buf, sizeof(buf)) != 0) {
        FAILS++;
        fprintf(stderr, "FIPSCHECK_get_binary_path FAIL\n");
    }

/* test FIPSCHECK_get_library_path
 * Auxiliary function - returns path pointing to the shared library file with
 * a name libname and containing a symbol symbolname. The path buffer must be
 * large enough to hold the path, otherwise it is truncated. */
    if (FIPSCHECK_get_library_path("libfipscheck.so.1", "FIPSCHECK_verify",
                  buf, sizeof(buf)) != 0) {
	 FAILS++;
         fprintf(stderr, "FIPSCHECK_get_library_path FAIL\n");
    }

/* test FIPSCHECK_verify_files
 * This will invoke fipscheck to verify the HMAC checksums of the files in
 * the NULL terminated array of pointers. The same pitfalls which might
 * cause verification errors apply as above. */
    if (FIPSCHECK_verify_files(files) != 0) {
         FAILS++;
         fprintf(stderr, "FIPSCHECK_verify_files\n");
    }

/* test FIPSCHECK_kernel_fips_mode
 * Auxiliary function - returns the value of the kernel fips mode flag. */
    printf("KERNEL_FIPS_MODE_FLAG %d\n", FIPSCHECK_kernel_fips_mode());

    return FAILS;
}
